Usage
assignTax(fasta, template = NULL, taxonomy = NULL, ksize = 8, iters = 100, cutoff = 80,
processors = 1, dir.out = "assignTax_out")
Arguments
fasta
a fasta file of rRNA sequences to be assigned with taxonomies, e.g. a set of sequences picked as the representatives of OTUs.
template
a faste file of rRNA reference sequences, default to download "Silva_119_provisional_release.zip" under "qiime" directory from SILVA archive under , and extract "Silva_119_rep_set97.fna", a representative set of SILVA rRNA references of version119 at 97% sequence identity.
taxonomy
a taxonomic path file mapping to the template file, default to load matched "taxonomy" stored in the package.
ksize, iters, cutoff, processors
parameters used in Classify.seqs by Mothur. ksize, kmer size which is a search option with the 'Wang' method and by default to 8. iters, iterations by default 100 to calculate the bootstrap confidence score for the assigned taxonomy. cutoff, a bootstrap confidence score for the taxonomy assignment, by default 80, which means a minimum 80% sequences were assigned by the same taxonomy, a higher value gives a more strict taxonomy assignment. processors, the number of central processing units you use to run the command, by default to 1. dir.out
a directory where the assigned files were outputted, by default to create assignTax_out directory and output assigned files under this directory.